//@line 36 "/builds/slave/linux64_repack/build/l10n-central/de/browser/firefox-l10n.js"

//@line 38 "/builds/slave/linux64_repack/build/l10n-central/de/browser/firefox-l10n.js"

pref("general.useragent.locale", "de");
